@@ -11,17 +11,24 @@ use core::time::Duration;
 
 use embedded_hal::delay::blocking::DelayUs;
 
+#[cfg(feature = "log")]
+use log::debug;
+
+#[cfg(feature = "defmt")]
+use defmt::debug;
+
 #[cfg(feature = "structopt")]
 use structopt::StructOpt;
 
 #[cfg(feature = "std")]
-use crate::std::string::ToString;
+use std::string::ToString;
 
 use crate::{Receive, State, Transmit};
 
 /// BlockingOptions for blocking radio functions
 #[derive(Clone, PartialEq, Debug)]
 #[cfg_attr(feature = "structopt", derive(StructOpt))]
+#[cfg_attr(feature = "defmt", derive(defmt::Format))]
 pub struct BlockingOptions {
     /// Interval for polling for device state
     #[cfg_attr(feature="structopt", structopt(long, default_value="100us", parse(try_from_str=crate::duration_from_str)))]
@@ -44,6 +51,7 @@ impl Default for BlockingOptions {
 /// BlockingError wraps radio error type to provie a `Timeout` variant
 #[derive(Clone, Debug, PartialEq)]
 #[cfg_attr(feature = "thiserror", derive(thiserror::Error))]
+#[cfg_attr(feature = "defmt", derive(defmt::Format))]
 pub enum BlockingError<E> {
     #[cfg_attr(feature = "thiserror", error("Inner: {0}"))]
     Inner(E),
@@ -94,7 +102,7 @@ pub trait BlockingTransmit<E: Debug> {
 
 impl<T, E> BlockingTransmit<E> for T
 where
-    T: Transmit<Error = E> + DelayUs<u32>,
+    T: Transmit<Error = E> + DelayUs,
     E: Debug,
 {
     fn do_transmit(
@@ -110,6 +118,7 @@ where
         loop {
             // Check for transmit complete
             if self.check_transmit()? {
+                #[cfg(any(feature = "log", feature = "defmt"))]
                 debug!("Blocking send complete");
                 break;
             }
@@ -117,6 +126,7 @@ where
             // Update poll time and timeout if overrun
             c += tx_options.poll_interval.as_micros();
             if c > t {
+                #[cfg(any(feature = "log", feature = "defmt"))]
                 debug!("Blocking send timeout");
                 return Err(BlockingError::Timeout);
             }
@@ -177,7 +187,7 @@ pub trait BlockingReceive<I, E> {
 
 impl<T, I, E> BlockingReceive<I, E> for T
 where
-    T: Receive<Info = I, Error = E> + DelayUs<u32>,
+    T: Receive<Info = I, Error = E> + DelayUs,
     <T as Receive>::Info: Debug,
     I: Debug,
     E: Debug,
@@ -200,6 +210,7 @@ where
 
             c += rx_options.poll_interval.as_micros();
             if c > t {
+                #[cfg(any(feature = "log", feature = "defmt"))]
                 debug!("Blocking receive timeout");
                 return Err(BlockingError::Timeout);
             }
@@ -220,7 +231,7 @@ pub trait BlockingSetState<S, E> {
 
 impl<T, S, E> BlockingSetState<S, E> for T
 where
-    T: State<State = S, Error = E> + DelayUs<u32>,
+    T: State<State = S, Error = E> + DelayUs,
     S: Debug + core::cmp::PartialEq + Copy,
     E: Debug,
 {
@@ -247,6 +258,7 @@ where
             // Timeout eventually
             c += options.poll_interval.as_micros();
             if c > t {
+                #[cfg(any(feature = "log", feature = "defmt"))]
                 debug!("Blocking receive timeout");
                 return Err(BlockingError::Timeout);
             }
